Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(188)

Unified Diff: components/offline_pages/core/background/offliner.h

Issue 2566453002: [OfflinePages] Rename PRERENDERING_* result terminology to LOADING_* (Closed)
Patch Set: Updated histogram enum Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/core/background/offliner.h
diff --git a/components/offline_pages/core/background/offliner.h b/components/offline_pages/core/background/offliner.h
index 6cc51ecae5178853c2b621e3199e2f082fed4ddd..a0159de5bc3169fe9704ad02f1ef8d16984f1979 100644
--- a/components/offline_pages/core/background/offliner.h
+++ b/components/offline_pages/core/background/offliner.h
@@ -30,10 +30,10 @@ class Offliner {
SAVED = 2,
// RequestCoordinator canceled request.
REQUEST_COORDINATOR_CANCELED = 3,
- // Prerendering was canceled.
- PRERENDERING_CANCELED = 4,
- // Prerendering failed to load page.
- PRERENDERING_FAILED = 5,
+ // Loading was canceled.
+ LOADING_CANCELED = 4,
+ // Loader failed to load page.
+ LOADING_FAILED = 5,
// Failed to save loaded page.
SAVE_FAILED = 6,
// Foreground transition canceled request.
@@ -41,12 +41,12 @@ class Offliner {
// RequestCoordinator canceled request attempt per time limit.
REQUEST_COORDINATOR_TIMED_OUT = 8,
// The loader did not accept/start the request.
- PRERENDERING_NOT_STARTED = 9,
- // Prerendering failed with hard error so should not retry the request.
- PRERENDERING_FAILED_NO_RETRY = 10,
- // Prerendering failed with some error that suggests we should not continue
+ LOADING_NOT_STARTED = 9,
+ // Loader failed with hard error so should not retry the request.
+ LOADING_FAILED_NO_RETRY = 10,
+ // Loader failed with some error that suggests we should not continue
// processing another request at this time.
- PRERENDERING_FAILED_NO_NEXT = 11,
+ LOADING_FAILED_NO_NEXT = 11,
// NOTE: insert new values above this line and update histogram enum too.
STATUS_COUNT
};

Powered by Google App Engine
This is Rietveld 408576698